searchNodes=[{"ref":"Mix.Tasks.Unicode.Download.html","title":"Mix.Tasks.Unicode.Download","type":"task","doc":"Downloads the required Unicode files to support Unicode"},{"ref":"Unicode.html","title":"Unicode","type":"module","doc":"Functions to introspect the Unicode character database and to provide fast codepoint lookups for scripts, blocks, categories and properties."},{"ref":"Unicode.html#alphabetic?/1","title":"Unicode.alphabetic?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) adhere to the Derived Core Property Alphabetic otherwise returns false. These are all characters that are usually used as representations of letters/syllabes/ in words/sentences. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.alphabetic?(?a) true iex&gt; Unicode.alphabetic?(&quot;A&quot;) true iex&gt; Unicode.alphabetic?(&quot;Elixir&quot;) true iex&gt; Unicode.alphabetic?(&quot;الإكسير&quot;) true iex&gt; Unicode.alphabetic?(&quot;foo, bar&quot;) # comma and whitespace false iex&gt; Unicode.alphabetic?(&quot;42&quot;) false iex&gt; Unicode.alphabetic?(&quot;龍王&quot;) true iex&gt; Unicode.alphabetic?(&quot;∑&quot;) # Summation, ∑ false iex&gt; Unicode.alphabetic?(&quot;Σ&quot;) # Greek capital letter sigma, Σ true"},{"ref":"Unicode.html#alphanumeric?/1","title":"Unicode.alphanumeric?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) are either alphabetic?/1 or numeric?/1 otherwise returns false. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.alphanumeric? &quot;1234&quot; true iex&gt; Unicode.alphanumeric? &quot;KeyserSöze1995&quot; true iex&gt; Unicode.alphanumeric? &quot;3段&quot; true iex&gt; Unicode.alphanumeric? &quot;dragon@example.com&quot; false"},{"ref":"Unicode.html#block/1","title":"Unicode.block/1","type":"function","doc":"Returns the block name of a codepoint or the list of block names for each codepoint in a string. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns in the case of a single codepoint, an atom block name in the case of a string, a list of atom block names for each codepoint in the codepoint_or_string Exmaples iex&gt; Unicode.block ?ä :latin_1_supplement iex&gt; Unicode.block ?A :basic_latin iex&gt; Unicode.block &quot;äA&quot; [:latin_1_supplement, :basic_latin]"},{"ref":"Unicode.html#cased?/1","title":"Unicode.cased?/1","type":"function","doc":"Returns either true if the codepoint has the :cased property or false. The :cased property means that this character has at least an upper and lower representation and possibly a titlecase representation too. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.cased? ?ယ false iex&gt; Unicode.cased? ?A true"},{"ref":"Unicode.html#category/1","title":"Unicode.category/1","type":"function","doc":"Returns the Unicode category for a codepoint or a list of categories for a string. Argument codepoint_or_string is a single integer codepoint or a String.t. Returns in the case of a single codepoint, an atom representing one of the categories listed below in the case of a string, a list representing the category for each codepoint in the string Notes THese categories match the names of the Unicode character classes used in various regular expression engines and in Unicode Sets. The full list of categories is: CategoryMatches :COther :CcControl :CfFormat :CnUnassigned :CoPrivate use :CsSurrogate :LLetter :LlLower case letter :LmModifier letter :LoOther letter :LtTitle case letter :LuUpper case letter :MMark :McSpacing mark :MeEnclosing mark :MnNon-spacing mark :NNumber :NdDecimal number :NlLetter number :NoOther number :PPunctuation :PcConnector punctuation :PdDash punctuation :PeClose punctuation :PfFinal punctuation :PiInitial punctuation :PoOther punctuation :PsOpen punctuation :SSymbol :ScCurrency symbol :SkModifier symbol :SmMathematical symbol :SoOther symbol :ZSeparator :ZlLine separator :ZpParagraph separator :ZsSpace separator Note too that the group level categories like :L, :M, :S and so on are not assigned to any codepoint. They can only be identified by combining the results for each of the subsidiary categories. Examples iex&gt; Unicode.category ?ä :Ll iex&gt; Unicode.category ?A :Lu iex&gt; Unicode.category ?🧐 :So iex&gt; Unicode.category ?+ :Sm iex&gt; Unicode.category ?1 :Nd iex&gt; Unicode.category &quot;äA&quot; [:Ll, :Lu]"},{"ref":"Unicode.html#class/1","title":"Unicode.class/1","type":"function","doc":"See Unicode.Category.category/1."},{"ref":"Unicode.html#digits?/1","title":"Unicode.digits?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) adhere to Unicode category :Nd otherwise returns false. This group of characters represents the decimal digits zero through nine (0..9) and the equivalents in non-Latin scripts. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples"},{"ref":"Unicode.html#downcase?/1","title":"Unicode.downcase?/1","type":"function","doc":"See Unicode.Property.lowercase?/1."},{"ref":"Unicode.html#emoji?/1","title":"Unicode.emoji?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) are emoji otherwise returns false. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.emoji? &quot;🧐🤓🤩🤩️🤯&quot; true"},{"ref":"Unicode.html#fetch_property/1","title":"Unicode.fetch_property/1","type":"function","doc":""},{"ref":"Unicode.html#get_property/1","title":"Unicode.get_property/1","type":"function","doc":""},{"ref":"Unicode.html#lowercase?/1","title":"Unicode.lowercase?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) the category :Ll otherwise returns false. Notice that there are many languages that do not have a distinction between cases. Their characters are not included in this group. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.lowercase?(?a) true iex&gt; Unicode.lowercase?(&quot;A&quot;) false iex&gt; Unicode.lowercase?(&quot;Elixir&quot;) false iex&gt; Unicode.lowercase?(&quot;léon&quot;) true iex&gt; Unicode.lowercase?(&quot;foo, bar&quot;) false iex&gt; Unicode.lowercase?(&quot;42&quot;) false iex&gt; Unicode.lowercase?(&quot;Σ&quot;) false iex&gt; Unicode.lowercase?(&quot;σ&quot;) true"},{"ref":"Unicode.html#math?/1","title":"Unicode.math?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) the category :Sm otherwise returns false. These are all characters whose primary usage is in mathematical concepts (and not in alphabets). Notice that the numerical digits are not part of this group. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.math?(?=) true iex&gt; Unicode.math?(&quot;=&quot;) true iex&gt; Unicode.math?(&quot;1+1=2&quot;) # Digits do not have the `:math` property. false iex&gt; Unicode.math?(&quot;परिस&quot;) false iex&gt; Unicode.math?(&quot;∑&quot;) # Summation, \\u2211 true iex&gt; Unicode.math?(&quot;Σ&quot;) # Greek capital letter sigma, \\u03a3 false"},{"ref":"Unicode.html#numeric?/1","title":"Unicode.numeric?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) adhere to Unicode categories :Nd, :Nl and :No otherwise returns false. This group of characters represents the decimal digits zero through nine (0..9) and the equivalents in non-Latin scripts. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.numeric?(&quot;65535&quot;) true iex&gt; Unicode.numeric?(&quot;42&quot;) true iex&gt; Unicode.numeric?(&quot;lapis philosophorum&quot;) false"},{"ref":"Unicode.html#properties/1","title":"Unicode.properties/1","type":"function","doc":"Returns the list of properties of each codepoint in a given string or the list of properties for a given string. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns in the case of a single codepoint, an atom list of properties in the case of a string, a list of atom lisr for each codepoint in the codepoint_or_string Exmaples iex&gt; Unicode.properties 0x1bf0 [:alphabetic, :case_ignorable] iex&gt; Unicode.properties ?A [:alphabetic, :uppercase, :cased] iex&gt; Unicode.properties ?+ [:math] iex&gt; Unicode.properties &quot;a1+&quot; [[:alphabetic, :lowercase, :cased], [:numeric, :emoji], [:math]]"},{"ref":"Unicode.html#property_aliases/0","title":"Unicode.property_aliases/0","type":"function","doc":"Returns a map of aliases mapping property names to a module that serves that property"},{"ref":"Unicode.html#ranges/0","title":"Unicode.ranges/0","type":"function","doc":"Returns a list of tuples representing the valid ranges of Unicode code points. This information is derived from the block ranges as defined by Unicode.Block.blocks/0."},{"ref":"Unicode.html#script/1","title":"Unicode.script/1","type":"function","doc":"Returns the script name of a codepoint or the list of block names for each codepoint in a string. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns in the case of a single codepoint, a string script name in the case of a string, a list of string script names for each codepoint in the codepoint_or_string Exmaples iex&gt; Unicode.script ?ä &quot;latin&quot; iex&gt; Unicode.script ?خ &quot;arabic&quot; iex&gt; Unicode.script ?अ &quot;devanagari&quot; iex&gt; Unicode.script ?א &quot;hebrew&quot; iex&gt; Unicode.script ?Ж &quot;cyrillic&quot; iex&gt; Unicode.script ?δ &quot;greek&quot; iex&gt; Unicode.script ?ก &quot;thai&quot; iex&gt; Unicode.script ?ယ &quot;myanmar&quot;"},{"ref":"Unicode.html#unaccent/1","title":"Unicode.unaccent/1","type":"function","doc":"Removes accents (diacritical marks) from a string. Arguments string is any String.t Returns A string with all diacritical marks removed Notes The string is first normalised to :nfd form and then all characters in the block :comnbining_diacritical_marks is removed from the string Example iex&gt; Unicode.unaccent(&quot;Et Ça sera sa moitié.&quot;) &quot;Et Ca sera sa moitie.&quot;"},{"ref":"Unicode.html#upcase?/1","title":"Unicode.upcase?/1","type":"function","doc":"See Unicode.Property.uppercase?/1."},{"ref":"Unicode.html#uppercase?/1","title":"Unicode.uppercase?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) the category :Lu otherwise returns false. Notice that there are many languages that do not have a distinction between cases. Their characters are not included in this group. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.uppercase?(?a) false iex&gt; Unicode.uppercase?(&quot;A&quot;) true iex&gt; Unicode.uppercase?(&quot;Elixir&quot;) false iex&gt; Unicode.uppercase?(&quot;CAMEMBERT&quot;) true iex&gt; Unicode.uppercase?(&quot;foo, bar&quot;) false iex&gt; Unicode.uppercase?(&quot;42&quot;) false iex&gt; Unicode.uppercase?(&quot;Σ&quot;) true iex&gt; Unicode.uppercase?(&quot;σ&quot;) false"},{"ref":"Unicode.html#version/0","title":"Unicode.version/0","type":"function","doc":"Returns the version of Unicode in use."},{"ref":"Unicode.html#t:codepoint/0","title":"Unicode.codepoint/0","type":"type","doc":""},{"ref":"Unicode.html#t:codepoint_or_string/0","title":"Unicode.codepoint_or_string/0","type":"type","doc":""},{"ref":"Unicode.Block.html","title":"Unicode.Block","type":"module","doc":"Functions to introspect Unicode blocks for binaries (Strings) and codepoints."},{"ref":"Unicode.Block.html#aliases/0","title":"Unicode.Block.aliases/0","type":"function","doc":"Returns a map of aliases for Unicode blocks. An alias is an alternative name for referring to a block. Aliases are resolved by the fetch/1 and get/1 functions."},{"ref":"Unicode.Block.html#block/1","title":"Unicode.Block.block/1","type":"function","doc":"Returns the block name(s) for the given binary or codepoint. In the case of a codepoint, a single block name is returned. For a binary a list of distinct block names represented by the graphemes in the binary is returned."},{"ref":"Unicode.Block.html#blocks/0","title":"Unicode.Block.blocks/0","type":"function","doc":"Returns the map of Unicode blocks. The block name is the map key and a list of codepoint ranges as tuples as the value."},{"ref":"Unicode.Block.html#count/1","title":"Unicode.Block.count/1","type":"function","doc":"Returns the count of the number of characters for a given block. Aliases are resolved by this function. Example iex&gt; Unicode.Block.count(:old_north_arabian) 32"},{"ref":"Unicode.Block.html#fetch/1","title":"Unicode.Block.fetch/1","type":"function","doc":"Returns the Unicode ranges for a given block as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either {:ok, range_list} or :error."},{"ref":"Unicode.Block.html#get/1","title":"Unicode.Block.get/1","type":"function","doc":"Returns the Unicode ranges for a given block as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either range_list or nil."},{"ref":"Unicode.Block.html#known_blocks/0","title":"Unicode.Block.known_blocks/0","type":"function","doc":"Returns a list of known Unicode block names. This function does not return the names of any block aliases."},{"ref":"Unicode.Block.html#ranges/0","title":"Unicode.Block.ranges/0","type":"function","doc":"Returns a list of tuples representing the valid ranges of Unicode code points."},{"ref":"Unicode.Category.html","title":"Unicode.Category","type":"module","doc":"Functions to introspect Unicode general categories for binaries (Strings) and codepoints."},{"ref":"Unicode.Category.html#aliases/0","title":"Unicode.Category.aliases/0","type":"function","doc":"Returns a map of aliases for Unicode categories. An alias is an alternative name for referring to a category. Aliases are resolved by the fetch/1 and get/1 functions."},{"ref":"Unicode.Category.html#categories/0","title":"Unicode.Category.categories/0","type":"function","doc":"Returns the map of Unicode character categories. The category name is the map key and a list of codepoint ranges as tuples as the value."},{"ref":"Unicode.Category.html#category/1","title":"Unicode.Category.category/1","type":"function","doc":"Returns the category name(s) for the given binary or codepoint. In the case of a codepoint, a single category name is returned. For a binary a list of distinct category names represented by the graphemes in the binary is returned."},{"ref":"Unicode.Category.html#count/1","title":"Unicode.Category.count/1","type":"function","doc":"Return the count of characters in a given category. Example iex&gt; Unicode.Category.count(:Ll) 2151 iex&gt; Unicode.Category.count(:Nd) 630"},{"ref":"Unicode.Category.html#fetch/1","title":"Unicode.Category.fetch/1","type":"function","doc":"Returns the Unicode ranges for a given category as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either {:ok, range_list} or :error."},{"ref":"Unicode.Category.html#get/1","title":"Unicode.Category.get/1","type":"function","doc":"Returns the Unicode ranges for a given category as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either range_list or nil."},{"ref":"Unicode.Category.html#known_categories/0","title":"Unicode.Category.known_categories/0","type":"function","doc":"Returns a list of known Unicode category names. This function does not return the names of any category aliases."},{"ref":"Unicode.CombiningClass.html","title":"Unicode.CombiningClass","type":"module","doc":"Functions to introspect Unicode canonical combining classes for binaries (Strings) and codepoints."},{"ref":"Unicode.CombiningClass.html#aliases/0","title":"Unicode.CombiningClass.aliases/0","type":"function","doc":"Returns a map of aliases for Unicode canonical combining classes.. An alias is an alternative name for referring to a class. Aliases are resolved by the fetch/1 and get/1 functions."},{"ref":"Unicode.CombiningClass.html#combining_class/1","title":"Unicode.CombiningClass.combining_class/1","type":"function","doc":"Returns the canonical combining class name(s) for the given binary or codepoint. In the case of a codepoint, a single class name is returned. For a binary a list of distinct class names represented by the graphemes in the binary is returned."},{"ref":"Unicode.CombiningClass.html#combining_classes/0","title":"Unicode.CombiningClass.combining_classes/0","type":"function","doc":"Returns the map of Unicode canonical combining classes.. The class name is the map key and a list of codepoint ranges as tuples as the value."},{"ref":"Unicode.CombiningClass.html#count/1","title":"Unicode.CombiningClass.count/1","type":"function","doc":"Returns the count of the number of characters for a given canonical combining class. Example iex&gt; Unicode.CombiningClass.count(230) 482"},{"ref":"Unicode.CombiningClass.html#fetch/1","title":"Unicode.CombiningClass.fetch/1","type":"function","doc":"Returns the Unicode ranges for a given canonical combining class as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either {:ok, range_list} or :error."},{"ref":"Unicode.CombiningClass.html#get/1","title":"Unicode.CombiningClass.get/1","type":"function","doc":"Returns the Unicode ranges for a given canonical combining class as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either range_list or nil."},{"ref":"Unicode.CombiningClass.html#known_combining_classes/0","title":"Unicode.CombiningClass.known_combining_classes/0","type":"function","doc":"Returns a list of known Unicode canonical combining class names. This function does not return the names of any class aliases."},{"ref":"Unicode.Property.html","title":"Unicode.Property","type":"module","doc":"Functions to introspect Unicode properties for binaries (Strings) and codepoints."},{"ref":"Unicode.Property.html#alphabetic/1","title":"Unicode.Property.alphabetic/1","type":"function","doc":"Returns :alphabetic or nil based upon whether the given codepoint or binary is all alphabetic characters. This is useful when the desired result is truthy or falsy Example iex&gt; Unicode.Property.alphabetic &quot;abc&quot; :alphabetic iex&gt; Unicode.Property.alphabetic &quot;123&quot; nil"},{"ref":"Unicode.Property.html#alphabetic?/1","title":"Unicode.Property.alphabetic?/1","type":"function","doc":"Returns a boolean based upon whether the given codepoint or binary is all alphabetic characters. Example iex&gt; Unicode.Property.alphabetic? &quot;abc&quot; true iex&gt; Unicode.Property.alphabetic? &quot;123&quot; false"},{"ref":"Unicode.Property.html#alphanumeric/1","title":"Unicode.Property.alphanumeric/1","type":"function","doc":"Returns :alphanumeric or nil based upon whether the given codepoint or binary is all alphanumeric characters. This is useful when the desired result is truthy or falsy Example iex&gt; Unicode.Property.alphanumeric &quot;123abc&quot; :alphanumeric iex&gt; Unicode.Property.alphanumeric &quot;???&quot; nil"},{"ref":"Unicode.Property.html#alphanumeric?/1","title":"Unicode.Property.alphanumeric?/1","type":"function","doc":"Returns a boolean based upon whether the given codepoint or binary is all alphanumeric characters. Example iex&gt; Unicode.Property.alphanumeric? &quot;123abc&quot; true iex&gt; Unicode.Property.alphanumeric? &quot;⅔&quot; false"},{"ref":"Unicode.Property.html#case_ignorable/1","title":"Unicode.Property.case_ignorable/1","type":"function","doc":"Returns :case_ignorable or nil based upon whether the given codepoint or binary is all case ignorable characters. This is useful when the desired result is truthy or falsy Example iex&gt; Unicode.Property.case_ignorable &quot;.:^&quot; :case_ignorable iex&gt; Unicode.Property.case_ignorable &quot;123abc&quot; nil"},{"ref":"Unicode.Property.html#case_ignorable?/1","title":"Unicode.Property.case_ignorable?/1","type":"function","doc":"Returns a boolean based upon whether the given codepoint or binary is all case ignorable characters. Example iex&gt; Unicode.Property.case_ignorable? &quot;.:^&quot; true iex&gt; Unicode.Property.case_ignorable? &quot;123abc&quot; false"},{"ref":"Unicode.Property.html#cased/1","title":"Unicode.Property.cased/1","type":"function","doc":"Returns :cased or nil based upon whether the given codepoint or binary is all cased characters. This is useful when the desired result is truthy or falsy Example iex&gt; Unicode.Property.cased &quot;abc&quot; :cased iex&gt; Unicode.Property.cased &quot;123&quot; nil"},{"ref":"Unicode.Property.html#cased?/1","title":"Unicode.Property.cased?/1","type":"function","doc":"Returns a boolean based upon whether the given codepoint or binary is all cased characters. Example iex&gt; Unicode.Property.cased? &quot;abc&quot; true iex&gt; Unicode.Property.cased? &quot;123&quot; false"},{"ref":"Unicode.Property.html#count/1","title":"Unicode.Property.count/1","type":"function","doc":"Returns the count of the number of characters for a given property. Example iex&gt; Unicode.Property.count(:lowercase) 2340"},{"ref":"Unicode.Property.html#default_ignorable_code_point/1","title":"Unicode.Property.default_ignorable_code_point/1","type":"function","doc":""},{"ref":"Unicode.Property.html#default_ignorable_code_point?/1","title":"Unicode.Property.default_ignorable_code_point?/1","type":"function","doc":""},{"ref":"Unicode.Property.html#emoji?/1","title":"Unicode.Property.emoji?/1","type":"function","doc":"Returns a boolean based upon whether the given codepoint or binary is all emoji characters. Note that some characters are unexpectedly emoji because they are part of a multicodepoint combination. For example, the numbers 0 through 9 are emoji because they form part of the keycap emoji codepoints. Example iex&gt; Unicode.Property.emoji? &quot;🔥&quot; true iex&gt; Unicode.Property.emoji? &quot;1&quot; true iex&gt; Unicode.Property.emoji? &quot;abc&quot; false"},{"ref":"Unicode.Property.html#extended_numeric/1","title":"Unicode.Property.extended_numeric/1","type":"function","doc":"Returns :extended_numeric or nil based upon whether the given codepoint or binary is all alphanumeric characters. Extended numberic includes fractions, superscripts, subscripts and other characters in the category No. This is useful when the desired result is truthy or falsy Example iex&gt; Unicode.Property.extended_numeric &quot;123&quot; :extended_numeric iex&gt; Unicode.Property.extended_numeric &quot;⅔&quot; :extended_numeric iex&gt; Unicode.Property.extended_numeric &quot;-123&quot; nil"},{"ref":"Unicode.Property.html#extended_numeric?/1","title":"Unicode.Property.extended_numeric?/1","type":"function","doc":"Returns a boolean based upon whether the given codepoint or binary is all numberic characters. Example iex&gt; Unicode.Property.extended_numeric? &quot;123&quot; true iex&gt; Unicode.Property.extended_numeric? &quot;⅔&quot; true"},{"ref":"Unicode.Property.html#known_properties/0","title":"Unicode.Property.known_properties/0","type":"function","doc":"Returns a list of known Unicode property names. This function does not return the names of any property aliases."},{"ref":"Unicode.Property.html#lowercase/1","title":"Unicode.Property.lowercase/1","type":"function","doc":"Returns :lowercase or nil based upon whether the given codepoint or binary is all lowercase characters. This is useful when the desired result is truthy or falsy Example iex&gt; Unicode.Property.lowercase &quot;abc&quot; :lowercase iex&gt; Unicode.Property.lowercase &quot;ABC&quot; nil"},{"ref":"Unicode.Property.html#lowercase?/1","title":"Unicode.Property.lowercase?/1","type":"function","doc":"Returns a boolean based upon whether the given codepoint or binary is all lowercase characters. Example iex&gt; Unicode.Property.lowercase? &quot;abc&quot; true iex&gt; Unicode.Property.lowercase? &quot;ABC&quot; false"},{"ref":"Unicode.Property.html#math/1","title":"Unicode.Property.math/1","type":"function","doc":"Returns :math or nil based upon whether the given codepoint or binary is all math characters. This is useful when the desired result is truthy or falsy Example iex&gt; Unicode.Property.math &quot;+&lt;&gt;=^&quot; :math iex&gt; Unicode.Property.math &quot;*/&quot; nil"},{"ref":"Unicode.Property.html#math?/1","title":"Unicode.Property.math?/1","type":"function","doc":"Returns a boolean based upon whether the given codepoint or binary is all math characters. Example iex&gt; Unicode.Property.math? &quot;+&lt;&gt;^&quot; true iex&gt; Unicode.Property.math? &quot;abc&quot; false"},{"ref":"Unicode.Property.html#numeric/1","title":"Unicode.Property.numeric/1","type":"function","doc":"Returns :numeric or nil based upon whether the given codepoint or binary is all numeric characters. This is useful when the desired result is truthy or falsy Example iex&gt; Unicode.Property.numeric &quot;123&quot; :numeric iex&gt; Unicode.Property.numeric &quot;123a&quot; nil"},{"ref":"Unicode.Property.html#numeric?/1","title":"Unicode.Property.numeric?/1","type":"function","doc":"Returns a boolean based upon whether the given codepoint or binary is all numeric characters. Example iex&gt; Unicode.Property.numeric? &quot;123&quot; true iex&gt; Unicode.Property.numeric? &quot;123a&quot; false"},{"ref":"Unicode.Property.html#properties/0","title":"Unicode.Property.properties/0","type":"function","doc":"Returns the map of Unicode properties. The property name is the map key and a list of codepoint ranges as tuples as the value."},{"ref":"Unicode.Property.html#properties/1","title":"Unicode.Property.properties/1","type":"function","doc":"Returns the property name(s) for the given binary or codepoint. In the case of a codepoint, a single list of properties for that codepoint name is returned. For a binary a list of list for each codepoint in the binary is returned."},{"ref":"Unicode.Property.html#uppercase/1","title":"Unicode.Property.uppercase/1","type":"function","doc":"Returns :uppercase or nil based upon whether the given codepoint or binary is all uppercase characters. This is useful when the desired result is truthy or falsy Example iex&gt; Unicode.Property.uppercase &quot;ABC&quot; :uppercase iex&gt; Unicode.Property.uppercase &quot;abc&quot; nil"},{"ref":"Unicode.Property.html#uppercase?/1","title":"Unicode.Property.uppercase?/1","type":"function","doc":"Returns a boolean based upon whether the given codepoint or binary is all uppercase characters. Example iex&gt; Unicode.Property.uppercase? &quot;ABC&quot; true iex&gt; Unicode.Property.uppercase? &quot;abc&quot; false"},{"ref":"Unicode.Property.html#t:string_or_codepoint/0","title":"Unicode.Property.string_or_codepoint/0","type":"type","doc":""},{"ref":"Unicode.Script.html","title":"Unicode.Script","type":"module","doc":"Functions to introspect Unicode scripts for binaries (Strings) and codepoints."},{"ref":"Unicode.Script.html#aliases/0","title":"Unicode.Script.aliases/0","type":"function","doc":"Returns a map of aliases for Unicode scripts. An alias is an alternative name for referring to a script. Aliases are resolved by the fetch/1 and get/1 functions."},{"ref":"Unicode.Script.html#count/1","title":"Unicode.Script.count/1","type":"function","doc":"Returns the count of the number of characters for a given script. Example iex&gt; Unicode.Script.count(&quot;mongolian&quot;) 167"},{"ref":"Unicode.Script.html#fetch/1","title":"Unicode.Script.fetch/1","type":"function","doc":"Returns the Unicode ranges for a given script as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either {:ok, range_list} or :error."},{"ref":"Unicode.Script.html#get/1","title":"Unicode.Script.get/1","type":"function","doc":"Returns the Unicode ranges for a given script as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either range_list or nil."},{"ref":"Unicode.Script.html#known_scripts/0","title":"Unicode.Script.known_scripts/0","type":"function","doc":"Returns a list of known Unicode script names. This function does not return the names of any script aliases."},{"ref":"Unicode.Script.html#script/1","title":"Unicode.Script.script/1","type":"function","doc":"Returns the script name(s) for the given binary or codepoint. In the case of a codepoint, a single script name is returned. For a binary a list of distinct script names represented by the graphemes in the binary is returned."},{"ref":"Unicode.Script.html#scripts/0","title":"Unicode.Script.scripts/0","type":"function","doc":"Returns the map of Unicode scripts. The script name is the map key and a list of codepoint ranges as tuples as the value."},{"ref":"readme.html","title":"Unicode","type":"extras","doc":"Unicode Functions to return information about Unicode codepoints. Elixir string are UTF8-encoded Unicode binaries. This is a flexible and complete encoding scheme for the worlds many scripts, characters and emjois. However since its a variable lenght encoding (using between one and four bytes for UTF8) it is harder to use high-performance byte-oriented functions to decompose strings. Since checking strings and codepoints for certain attributes - like whether they are upper case, or symbols, or whitespace - is a common occurrence, a performant approach to such detection is useful. It is tempting to assume the use of US ASCII encoding and checking only for characters in that range. For example it is very common to see code in Elixir checking codepoint in ?a..?z to check for lowercase alphabetic characters. When the underlying programming language has no canonical form for a string beyond bytes this may be considered acceptable - the programmer is defining the script domain as he or she sees fit. However Elixir string are declared to be UTF8 encoded Unicode string it seems appropriate to make it easier to determins the characteristics of codepoints (and strings) using this standard. The Elixir standard library does not provide introspection beyond that required to support casing (String.downcase/1, String.upcase/1, String.capitalize/1). This library aims to fill in the blanks a little bit."},{"ref":"readme.html#additional-unicode-libraries","title":"Unicode - Additional Unicode libraries","type":"extras","doc":"ex_unicode provides basic introspection into Unicode codepoints and strings. Additional libraries (either releases or in development) buil upon this library): unicode_set implements functions to parse and match on unicode sets unicode_guards is a simple library implementing common function guards using unicode_set and ex_unicode unicode_string is a library to implement efficient string splitting and replacing based upon unicode sets unicode_transform implements the Unicode transform specification."},{"ref":"readme.html#unicode-functions","title":"Unicode - Unicode Functions","type":"extras","doc":"The following is a partial list of functions included in the library. See the documentation for the relevant module for further information: Codepoint ranges These functions return the codepoints as list of 2-tuples for the given property: Unicode.Block.blocks/0 Unicode.Script.scripts/0 Unicode.Category.categories/0 Unicode.CombiningClass.combining_classes/0 Basic introspection of codepoints and string The following functions return the block, script and category for codepoints and strings: Unicode.script/1 iex&gt; Unicode.script ?ä &quot;latin&quot; iex&gt; Unicode.script ?خ &quot;arabic&quot; iex&gt; Unicode.script ?अ &quot;devanagari&quot; Unicode.block/1 iex&gt; Unicode.block ?ä :latin_1_supplement iex&gt; Unicode.block ?A :basic_latin iex&gt; Unicode.block &quot;äA&quot; [:latin_1_supplement, :basic_latin] Unicode.category/1 iex&gt; Unicode.category ?ä :Ll iex&gt; Unicode.category ?A :Lu iex&gt; Unicode.category ?🧐 :So Unicode.properties/1 iex&gt; Unicode.properties 0x1bf0 [:alphabetic, :case_ignorable] iex&gt; Unicode.properties ?A [:alphabetic, :uppercase, :cased] iex&gt; Unicode.properties ?+ [:math] iex&gt; Unicode.properties &quot;a1+&quot; [[:alphabetic, :lowercase, :cased], [:numeric, :emoji], [:math]] Character classes These functions help filter codepoints and strings based upon their properties. They return a boolean result. Unicode.alphabetic?/1 Unicode.alphanumeric?/1 Unicode.digits?/1 Unicode.numeric?/1 Unicode.emoji?/1 Unicode.math?/1 Unicode.cased?/1 Unicode.lowercase?/1 Unicode.uppercase?/1&#39; &#39; Transformations The function Unicode.unaccent/1 attempts to transform a Unicode string into a subset of the Latin-1 alphabet by removing diacritical marks from text. It is not a full transformation (which will be available in the upcoming unicode_transform library.)"},{"ref":"readme.html#recognition","title":"Unicode - Recognition","type":"extras","doc":"The information functions are heavily inspired by @qqwy&#39;s elixir-unicode package and compatibility with some of the api is represented by including some of the doctests from that package."},{"ref":"readme.html#installation","title":"Unicode - Installation","type":"extras","doc":"The package can be installed by adding ex_unicode to your list of dependencies in mix.exs: def deps do [ {:ex_unicode, &quot;~&gt; 1.0&quot;} ] end The docs can be found at https://hexdocs.pm/ex_unicode."},{"ref":"license.html","title":"License","type":"extras","doc":"License Copyright 2018 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License."},{"ref":"changelog.html","title":"Changelog for Unicode v1.1.0","type":"extras","doc":"Changelog for Unicode v1.1.0 This is the changelog for Unicode v1.1.0 released on November 23rd, 2019. For older changelogs please consult the release tag on GitHub Breaking Changes Removed Unicode.Guards from this library and moved them to the unicode_set package. Enhancements Unicode.Category.categories/0 now returns the super categories as well as the subcategories. These super categories are computed at compile time by consolidating the relevant subcategories. Unicode.Category.category/1 will only return one category, and it will be the subcategory as it consistent with earlier releases. Add Unicode.ranges/0 that returns all Unicode codepoints as a list of 2-tuples representing the disjoint ranges of valid codepoints. The list is in sorted order. Add aliases/0 for Unicode.Category, Unicode.Script, Unicode.Block, and Unicode.CombiningClass which returns the alias map for the relevant module. Add fetch/1 and get/1 for Unicode.Category, Unicode.Script, Unicode.Block, and Unicode.CombiningClass. These functions leverage Unicode property value aliases for retrieving codepoints. Add Unicode.fetch_property/1 and Unicode.get_property/1 that return the module responsible for handling a given Unicode property. Add Unicode.compact_ranges/1 that given a list of 2-tuple ranges will compact them into as small a list of contiguous blocks as possible Documented all public functions Changelog for Unicode v1.0.0 This is the changelog for Unicode v1.0.0 released on November 14th, 2019. For older changelogs please consult the release tag on GitHub Breaking Changes Rename the module prefix to Unicode since this package is not linked in any way to the Cldr family. The hex package is renamed to ex_unicode. Changelog for Cldr Unicode v0.7.1 This is the changelog for Unicode v0.7.1 released on November 12th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Fixes count/1 for blocks, scripts and categories Replace deprecated String.normalize/2 with :unicode.characters_to_nfd_binary/ for OTP release 20 and later. Changelog for Cldr Unicode v0.7.0 This is the changelog for Unicode v0.7.0 released on November 12th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Add is_whitespace/1 guard generator Changelog for Cldr Unicode v0.6.0 This is the changelog for Unicode v0.6.0 released on October 22nd, 2019. For older changelogs please consult the release tag on GitHub Enhancements Update to Emoji 12.1 Changelog for Cldr Unicode v0.5.0 This is the changelog for Unicode v0.5.0 released on May 12th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Update to Unicode 12.1 Changelog for Cldr Unicode v0.4.0 This is the changelog for Unicode v0.4.0 released on April 30th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Adds Cldr.Unicode.unaccent/1 Breaking Changes Block names are now atoms instead of strings Changelog for Cldr Unicode v0.3.0 This is the changelog for Unicode v0.3.0 released on March 28th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Updated to Unicode version 12 Changelog for Cldr Unicode v0.2.0 This is the changelog for Unicode v0.2.0 released on February 24th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Moves the public API to the Cldr.Unicode module. Updates and adds documentation to all public functions. Removes the text annotations from the compiled functions which materially reduces the size of the beam files. Changelog for Cldr Unicode v0.1.0 This is the changelog for Unicode v0.1.0 released on February 23rd, 2019. For older changelogs please consult the release tag on GitHub Enhancements Initial release"}]